==> haskell-cassava-megaparsec-1.0.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava-megaparsec
version: 1.0.0
id: cassava-megaparsec-1.0.0-GIwRN5OUeoUDXL3aDu4Up7
key: cassava-megaparsec-1.0.0-GIwRN5OUeoUDXL3aDu4Up7
license: MIT
maintainer: Mark Karpov <markkarpov@openmailbox.org>
author: Mark Karpov <markkarpov@openmailbox.org>
homepage: https://github.com/stackbuilders/cassava-megaparsec
synopsis: Megaparsec parser of CSV files that plays nicely with Cassava
description:
    Megaparsec parser of CSV files that plays nicely with Cassava.
category: Text, Web, CSV, Parsing
abi: e6cc16412f501b4565c209caedaab47d
exposed: True
exposed-modules:
    Data.Csv.Parser.Megaparsec
import-dirs: /usr/lib/ghc-8.4.3/site-local/cassava-megaparsec-1.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/cassava-megaparsec-1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/cassava-megaparsec-1.0.0
hs-libraries: HScassava-megaparsec-1.0.0-GIwRN5OUeoUDXL3aDu4Up7
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cassava-0.5.1.0-3ZYXqaDZNjS5l91vSOMT9S containers-0.5.11.0
    megaparsec-6.5.0-EOdm02h4sdCFcHfmPoA6xU
    unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cassava-0.5.1.0-3ZYXqaDZNjS5l91vSOMT9S=876f28b670e664f52a2f7983d1d55710
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             megaparsec-6.5.0-EOdm02h4sdCFcHfmPoA6xU=f15b63fc4d597deb03cc96e26ad0c981
             unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE=d999168fa5a35d048ce4f3e0442b4ae6
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-megaparsec-1.0.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava-megaparsec
version: 1.0.0
id: cassava-megaparsec-1.0.0-8p6QpzQabV7HgZkvw6GPBF
key: cassava-megaparsec-1.0.0-8p6QpzQabV7HgZkvw6GPBF
license: MIT
maintainer: Mark Karpov <markkarpov@openmailbox.org>
author: Mark Karpov <markkarpov@openmailbox.org>
homepage: https://github.com/stackbuilders/cassava-megaparsec
synopsis: Megaparsec parser of CSV files that plays nicely with Cassava
description:
    Megaparsec parser of CSV files that plays nicely with Cassava.
category: Text, Web, CSV, Parsing
abi: ea14e96e5bdc3b4114457abbc15c4da6
exposed: True
exposed-modules:
    Data.Csv.Parser.Megaparsec
import-dirs: /usr/lib/ghc-8.4.3/site-local/cassava-megaparsec-1.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/cassava-megaparsec-1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/cassava-megaparsec-1.0.0
hs-libraries: HScassava-megaparsec-1.0.0-8p6QpzQabV7HgZkvw6GPBF
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cassava-0.5.1.0-4Hv7RdXr6eYGO02f7Vtz8l containers-0.5.11.0
    megaparsec-6.5.0-EAa3rIxi4n03JyCLzR8YXh
    unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cassava-0.5.1.0-4Hv7RdXr6eYGO02f7Vtz8l=2602352440d3525e453c31dde73ecaab
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             megaparsec-6.5.0-EAa3rIxi4n03JyCLzR8YXh=ad08f17deaeae5d70f9a32210223f265
             unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE=d999168fa5a35d048ce4f3e0442b4ae6
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
